# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateContainerScanRecipeDetails(object):
    """
    The information for a new container scan recipe
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateContainerScanRecipeDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this CreateContainerScanRecipeDetails.
        :type display_name: str

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateContainerScanRecipeDetails.
        :type compartment_id: str

        :param scan_settings:
            The value to assign to the scan_settings property of this CreateContainerScanRecipeDetails.
        :type scan_settings: oci.vulnerability_scanning.models.ContainerScanSettings

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateContainerScanRecipeDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateContainerScanRecipeDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'display_name': 'str',
            'compartment_id': 'str',
            'scan_settings': 'ContainerScanSettings',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'compartment_id': 'compartmentId',
            'scan_settings': 'scanSettings',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._display_name = None
        self._compartment_id = None
        self._scan_settings = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def display_name(self):
        """
        Gets the display_name of this CreateContainerScanRecipeDetails.
        User friendly name of container scan recipe. If not present, will be auto-generated.


        :return: The display_name of this CreateContainerScanRecipeDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateContainerScanRecipeDetails.
        User friendly name of container scan recipe. If not present, will be auto-generated.


        :param display_name: The display_name of this CreateContainerScanRecipeDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateContainerScanRecipeDetails.
        The `OCID`__ of the container scan recipe's compartment

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this CreateContainerScanRecipeDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateContainerScanRecipeDetails.
        The `OCID`__ of the container scan recipe's compartment

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this CreateContainerScanRecipeDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def scan_settings(self):
        """
        **[Required]** Gets the scan_settings of this CreateContainerScanRecipeDetails.

        :return: The scan_settings of this CreateContainerScanRecipeDetails.
        :rtype: oci.vulnerability_scanning.models.ContainerScanSettings
        """
        return self._scan_settings

    @scan_settings.setter
    def scan_settings(self, scan_settings):
        """
        Sets the scan_settings of this CreateContainerScanRecipeDetails.

        :param scan_settings: The scan_settings of this CreateContainerScanRecipeDetails.
        :type: oci.vulnerability_scanning.models.ContainerScanSettings
        """
        self._scan_settings = scan_settings

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateContainerScanRecipeDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this CreateContainerScanRecipeDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateContainerScanRecipeDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this CreateContainerScanRecipeDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateContainerScanRecipeDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this CreateContainerScanRecipeDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateContainerScanRecipeDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this CreateContainerScanRecipeDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
